body {
    font-family: Verdana, Helvetica, Arial, sans-serif;
    font-size: 20pt;
    background-color: black;
    color: white;
}

body::-webkit-scrollbar {
    background-color: black;
    width: 3%;
}

body::-webkit-scrollbar-thumb {
    background-color: gray;
    border-radius: 3px;
}

a {
    color: #4682b4;
    text-decoration: none;
}

table {
    border-collapse: collapse;
}

table thead th {
    background-color: #444;
    text-align: center;
}

table tr {
    border-top: 1px solid #ccc;
}

table tr:nth-child(2n) {
    background-color: #444;
}

table tr th, table tr td {
    border: 1px solid #ccc;
}

img {
    max-width: 100%;
}
